==> MicrobiotaProcess_1.5.9.tar.gz: MicrobiotaProcess/R/alldata.R <==
#' @title (Data) Small subset of the HMP 16S dataset 
#'
#' @description Contained three datasets, featureda, sampleda, taxda
#' featureda contained 55 samples (nrow) and 1091 features (ncol)
#' sampleda contained 55 samples from 6 body sites of 10 subjects.
#' taxda contained 699 taxonomy by 6 rank. This datasets were built 
#' from the LEfSe.\url{http://huttenhower.sph.harvard.edu/webfm_send/129}
#' 
#' @name data-hmp_aerobiosis_small
#' @aliases hmp_aerobiosis_small
#' @docType data
#' @keywords data
#' @examples
#' data(hmp_aerobiosis_small)
NA

#' @title (Data) Genomic analysis identifies association of Fusobacterium 
#'               with colorectal carcinoma (2012)
#'
#'
#' @description This dataset was from the a study on colorectal cancer, 
#' publised in Genome Research (2012). This dataset had been removed samples 
#' with less than 500 reads, contained 91 Control and 86 Tumors. And It is 
#' belong to phyloseq class, contained otu_table and sample_data.
#'
#' @name data-kostic2012crc
#' @aliases kostic2012crc
#' @docType data
#' @keywords data
#' @examples
#' data(kostic2012crc)
NA

#' @title (Data) simulated dataset.
#' 
#'
#' @description This dataset was simulated. And it also was phyloseq class, 
#' contained otu_table and sample_data
#' 
#' @name data-test_otu_data
#' @aliases test_otu_data
#' @docType data
#' @keywords data
#' @examples
#' data(test_otu_data)
NA

#' @title (Data) An example data
#'
#'
#' @description This is a MPSE object example data.
#'
#' @name mouse.time.mpse
#' @aliases mouse.time.mpse
#' @docType data
#' @keywords data
NA

==> MicrobiotaProcess_1.8.1.tar.gz: MicrobiotaProcess/R/alldata.R <==
#' @title (Data) Small subset of the HMP 16S dataset 
#'
#' @description Contained three datasets, featureda, sampleda, taxda
#' featureda contained 55 samples (nrow) and 1091 features (ncol)
#' sampleda contained 55 samples from 6 body sites of 10 subjects.
#' taxda contained 699 taxonomy by 6 rank. This datasets were built 
#' from the LEfSe.\url{http://huttenhower.sph.harvard.edu/webfm_send/129}
#' 
#' @name data-hmp_aerobiosis_small
#' @aliases hmp_aerobiosis_small
#' @docType data
#' @keywords data
#' @examples
#' data(hmp_aerobiosis_small)
NA

#' @title (Data) Genomic analysis identifies association of Fusobacterium 
#'               with colorectal carcinoma (2012)
#'
#'
#' @description This dataset was from the a study on colorectal cancer, 
#' publised in Genome Research (2012). This dataset had been removed samples 
#' with less than 500 reads, contained 91 Control and 86 Tumors. And It is 
#' belong to MPSE class, contained otu_table and sample_data.
#'
#' @name data-kostic2012crc
#' @aliases kostic2012crc
#' @docType data
#' @keywords data
#' @examples
#' data(kostic2012crc)
NA

#' @title (Data) simulated dataset.
#' 
#'
#' @description This dataset was simulated. And it also was MPSE class, 
#' contained otu_table and sample_data
#' 
#' @name data-test_otu_data
#' @aliases test_otu_data
#' @docType data
#' @keywords data
#' @examples
#' data(test_otu_data)
NA

#' @title (Data) An example data
#'
#'
#' @description This is a MPSE object example data.
#'
#' @name mouse.time.mpse
#' @aliases mouse.time.mpse
#' @docType data
#' @keywords data
NA
